#
# spec file for package python-scour
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-scour
Version:        0.37
Release:        1.45
Summary:        An SVG scrubber
License:        Apache-2.0
Group:          Productivity/Graphics/Other
URL:            https://github.com/oberstet/scour
Source:         https://github.com/scour-project/scour/archive/v%{version}/scour-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-setuptools
Requires:       python-six >= 1.9.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      %{oldpython}-scour < 0.37
Provides:       scour = %{version}
BuildArch:      noarch
%python_subpackages

%description
Scour is a Python script that aggressively cleans SVG files, removing
a lot of "cruft" that certain tools or authors embed into their
documents.
The goal of scour is to provide an identically rendered image.

%prep
%setup -q -n scour-%{version}
# remove unwanted shebang
sed -i '/^#!/ d' scour/{scour.py,yocto_css.py,svg_transform.py}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/scour

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python testscour.py

%post
%python_install_alternative scour

%postun
%python_uninstall_alternative scour

%files %{python_files}
%license LICENSE
%doc *.md
%python_alternative %{_bindir}/scour
%{python_sitelib}/scour/
%{python_sitelib}/scour-*.egg-info

%changelog
* Mon Apr  1 2019 tchvatal@suse.com
- Conflict with old scour to avoid conflict on /usr/bin/scour
* Thu Mar 28 2019 tchvatal@suse.com
- Run spec-cleaner to remove few whitespacing problems
* Tue Mar 26 2019 pgajdos@suse.com
- require six >= 1.9.0
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 0.37
  * Fix escaping of quotes in attribute values.
  * A lot of performance improvements.
  * Fix exception when removing duplicated gradients while
    `--keep-unreferenced-defs` is used.
  * Remove some illegal optimizations of `m0 0` sub-path commands.
  * Fix and improve handling of boolean flags in elliptical arc path
    commands.
  * Fix exception when using two-number forms of the filter attributes
    `baseFrequency`, `order`, `radius` and `stdDeviation`.
  * Improve whitespace handling in text nodes fixing an issue where
    scouring added spaces in error and reducing file size in many cases.
  * Drop official support for Python 3.3.
- etc. see HISTORY.md for details.
- build also python3 variant
- run unit tests
- package LICENSE and *.md
* Mon Feb  6 2017 jengelh@inai.de
- Update description and RPM group
* Sat Jan  7 2017 i@marguerite.su
- update SOURCE URL
* Wed Jan  4 2017 plinnell@opensuse.org
- Update to 0.35
- Change log full history:
  https://github.com/scour-project/scour/blob/master/HISTORY.md
* Thu Jun 30 2016 perry.werneck@gmail.com
- Adding python-setuptools as a dependency;
  it's required to run scour.
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 0.30:
  * no changelog available
- update source URL
- point the source URL to pypi
- add BuildRequires python-setuptools and unzip
- fix end of line encoding of scour.py
- remove unwanted shebang of python sitelib files
- run setup.py build and install instead of copying the files
- remove the documentation files: not provided anymore
- add egg-info to the package
* Mon Jan 30 2012 saschpe@suse.de
- Ran spec-cleaner and did some minor cleanup
- Set license to SPDX style (Apache-2.0)
* Fri Jan 27 2012 i@marguerite.su
- initial package 0.26
